	subroutine diffopC2 (x,xx,px,ileft,cx,dim,eps,lspl)

!
!	Calculation of the differential operator L applied to the tension 
!	spline s, where Lu=eps*u''(x)+bb(x,eps)*u'(x)+cc(x,eps)*u(x)
!
!   INPUT:
!       x     = double precision variable, the point at which Ls
!               is evaluated
!       xx    = rank-one double precision array of size dimx+4,
!               the increasing array of knots, assumed to fulfill
!               the conditions:
!               xx(1)=xx(2)=xx(3)=xx(4)<xx(5)<...<xx(i)<xx(i+1)<...
!               <xx(dimx)<xx(dimx+1)=xx(dimx+2)=xx(dimx+3)=
!               xx(dimx+4); xx(1),...,xx(dimx+4) is the extended
!               partition with all interior knots of multiplicity 1,
!               and the boundary points of multiplicity 4
!       px    = rank-one double precision array of size dimx+3,
!               the array of tension parameters, assumed to be
!               nonnegative: px(i)>=0 is the tension parameter on
!               the subinterval [xx(i),xx(i+1));
!               px(1),px(2),px(3),px(dimx+1),px(dimx+2) and
!               px(dimx+3) can be arbitrary
!       ileft = integer variable, the index of the array xx such
!               that x is contained in the subinterval
!               [xx(ileft),xx(ileft+1)]
!       cx    = rank-two double precision array of shape dim by
!               dimx, the array of de Boor points associated with
!               the extended partition xx;
!               cx(1:dim,i) corresponds to the B-spline with the
!               support [xx(i),xx(i+4)]
!       dim   = integer variable, the extent of the first dimension
!               in the array cx, assumed to be positive
!       eps	  = double precision variable, the leading coefficient 
!				in the differential equation, assumed to be positive
!
!   AUXILIARY TERM:
!      dimx   = size(xx)-4
!
!   OUTPUT:
!       lspl  = rank-one double precision array of size dim, the
!               output value of the differential operator L applied 
!				to the tension spline at the point x
!

	use examplediffeqC2

	implicit none

	integer, intent(in) :: ileft,dim
	double precision, intent(in) :: x,xx(*),px(*),cx(dim,4),eps	
	double precision, intent(out) :: lspl(dim)

	double precision :: spl(dim),spl1der(dim),spl2der(dim)

!
!	Calculating the second, the first derivative and the value
!	of the tension spline at the point x
!
	call tension2der4C2 (x,xx(ileft-3:ileft+3),px(ileft-3:ileft+2),4,cx,dim,spl2der)
	call tension1der4C2 (x,xx(ileft-3:ileft+3),px(ileft-3:ileft+2),4,cx,dim,spl1der)
	call tension4C2 (x,xx(ileft-3:ileft+3),px(ileft-3:ileft+2),4,cx,dim,spl)
!
!	The final value of the differential operator
!
	lspl=eps*spl2der+bb(x,eps)*spl1der+cc(x,eps)*spl


	end subroutine diffopC2