	module examplediffeqC2

!
!	This module contains functions that define the boundary value 
!	problem from Example 8.2. In general, differential equation is 
!	given with
!	eps*u''(x)+bb(x,eps)*u'(x)+cc(x,eps)*u(x)=ff(x,eps),
!	and boundary values with
!	u(ax)=alpha(eps), u(bx)=beta(eps).
!	eps is assumed to be positive.
! 

	implicit none

	double precision, parameter :: ax=0.0d0, bx=1.0d0

	contains


	double precision function bb(x,eps)

	implicit none

	double precision, intent(in) :: x,eps

	bb=1.0d0

	end function bb



	double precision function cc(x,eps)

	implicit none

	double precision, intent(in) :: x,eps

	cc=-(1.0d0+eps)

	end function cc



	double precision function ff(x,eps)

	implicit none

	double precision, intent(in) :: x,eps

	ff=0.0d0

	end function ff



	double precision function alpha(eps)

	implicit none

	double precision, intent(in) :: eps

	alpha=1.0d0+exp(-1.0d0)

	end function alpha



	double precision function beta(eps)

	implicit none

	double precision, intent(in) :: eps

	beta=1.0d0+exp(-(1+eps)/eps)

	end function beta



	subroutine pchoiceC2(eps,xx,dimx,px)

!	
!	This subroutine defines the choice of tension parameters
!
!   INPUT:
!       eps	  = double precision variable, the leading coefficient 
!				in the differential equation, assumed to be positive
!       xx    = rank-one double precision array of size dimx+4,
!               the increasing array of knots, assumed to fulfill
!               the conditions:
!               xx(1)=xx(2)=xx(3)=xx(4)<xx(5)<...<xx(i)<xx(i+1)<...
!               <xx(dimx)<xx(dimx+1)=xx(dimx+2)=xx(dimx+3)=
!               xx(dimx+4); xx(1),...,xx(dimx+4) is the extended
!               partition with all interior knots of multiplicity 1,
!               and the boundary points of multiplicity 4
!		dimx  = integer variable, the size of array xx 
!
!
!	OUTPUT:
!       px    = rank-one double precision array of size dimx-1,
!               the array of tension parameters:
!               px(i)>=0 is the tension parameter on the subinterval
!               [xx(i),xx(i+1))
!              

	implicit none

	integer, intent(in) :: dimx
	double precision, intent(in) :: eps,xx(dimx)
	double precision, intent(out) :: px(dimx-1)

	px(1:3)=0.0d0
	px(4:dimx-4)=(1.0d0+eps)/eps
	px(dimx-3:dimx-1)=0.0d0

	end subroutine pchoiceC2



	double precision function solution (x,eps)

!
!	Exact solution of the singualarly perturbed differential two-point 
!	boundary value problem:
!	y(x)=exp(-x*(1.0d0+eps)/eps)+exp(x-1.0d0)
!
!   INPUT:
!       x     = double precision variable, the point at which the
!               solution is evaluated
!       eps	  = double precision variable, the leading coefficient 
!				in the differential equation, assumed to be positive


	implicit none

	double precision, intent(in) :: x,eps

	solution=exp(-x*(1.0d0+eps)/eps)+exp(x-1.0d0)


	end function solution


	end module examplediffeqC2