	subroutine linsystemC2 (eps,n,xx,px,c)

!
!	Forming and solving the system of linear equations, comming from 
!	the collocation method with tension splines at the knots of the
!	partition of [ax,bx]. The differential equation is given with
!	eps*u''(x)+bb(x,eps)*u'(x)+cc(x,eps)*u(x)=ff(x,eps),
!	and boundary values with
!	u(ax)=alpha(eps), u(bx)=beta(eps).
!	eps is assumed to be positive.
!
!   INPUT:
!       eps	  = double precision variable, the leading coefficient 
!				in the differential equation, assumed to be positive
!		n	  = integer variable, the number of the nontrivial 
!				subintervals in [ax,bx]
!
!   OUTPUT:
!       xx    = rank-one double precision array of size n+7,
!               the increasing array of knots defined as:
!               xx(1)=xx(2)=xx(3)=xx(4)=ax,
!				xx(n+4)=xx(n+5)=xx(n+6)=xx(n+7)=bx and
!				xx(i+4)=ax*(n-i)/n+bx*i/n for i=1,...,n-1;
!               xx(1),...,xx(n+7) is the extended partition
!               with all interior knots of multiplicity 1,
!               and the boundary points of multiplicity 4
!       px    = rank-one double precision array of size n+6, the  
!               array of tension parameters: px(i)>=0 is the tension
!               parameter on the subinterval [xx(i),xx(i+1));
!               for the choice of the parameters see Example 8.
!       c     = rank-one double precision array of size n+3,
!               the array of de Boor points associated with the 
!               extended partition xx;
!               c(i) corresponds to the B-spline with the support
!               [xx(i),xx(i+4)]
!				c is the solution of the linear system 
!               

	use examplediffeqC2

	implicit none

	double precision, intent(in) :: eps
	integer, intent(in) :: n
	double precision, intent (out) :: xx(n+7),px(n+6),c(n+3)

	double precision :: cx3(3,-3:0),lspl(3),a(3,n+3),f(n+3)
	integer :: i 
	integer, dimension(3), parameter :: reverse=(/ 3,2,1 /)
	double precision, dimension(3), parameter :: firstlast=(/ 0.0d0,1.0d0,0.0d0 /)	

!
!	Defining the array of knots
!
	xx(1:4)=0.0d0
	do i=1,n-1
		xx(i+4)=ax*(n-dble(i))/n+bx*dble(i)/n
	enddo
	xx(n+4:n+7)=1.0d0
!
!	The choice of the tension parameters
!
	call pchoiceC2(eps,xx,n+7,px)
!
!	Forming the matrix of the linear system in band storage mode,
!	and the vector containing the right-hand sides of the linear
!	system
!	
	a(1:3,1)=firstlast
	c(1)=alpha(eps)

	cx3=0.0d0
	cx3(1,-3)=1.0d0
	cx3(2,-2)=1.0d0
	cx3(3,-1)=1.0d0
	do i=4,n+3
		call diffopC2 (xx(i),xx,px,i,cx3,3,eps,lspl)
		a(1:3,i-2)=lspl(reverse)
		c(i-2)=ff(xx(i),eps)
	enddo
	cx3=0.0d0
	cx3(1,-2)=1.0d0
	cx3(2,-1)=1.0d0
	cx3(3,0)=1.0d0
	call diffopC2 (xx(n+4),xx,px,n+3,cx3,3,eps,lspl)
	a(1:3,n+2)=lspl(reverse)
	c(n+2)=ff(xx(n+4),eps)

	a(1:3,n+3)=firstlast
	c(n+3)=beta(eps)
!
!	Calling the IMSL subroutine for solving a real tridiagonal 
!	system of linear equations
!
	call DLSLTR(n+3,a(3,1:n+3),a(2,1:n+3),a(1,1:n+3),c)


	end subroutine linsystemC2